# Welcome to NeuroGym

NeuroGym is a curated collection of neuroscience tasks with a common interface.
The goal is to facilitate training of neural network models on neuroscience tasks.

NeuroGym inherits from the machine learning toolkit [Gymnasium](https://gymnasium.farama.org/), a maintained fork of [OpenAI’s Gym library](https://github.com/openai/gym). It allows a wide range of well established machine learning algorithms to be easily trained on behavioral paradigms relevant for the neuroscience community.
NeuroGym also incorporates several properties and functions (e.g. continuous-time and trial-based tasks) that are important for neuroscience applications.
The toolkit also includes various modifier functions that allow easy configuration of new tasks.

![alt tag](pipeline.png)

🐛 Bugs reports and ⭐ features requests [here](https://github.com/neurogym/neurogym/issues)

🔧 [Pull Requests](https://github.com/neurogym/neurogym/pulls)

For more details about how to contribute, see the [contribution guidelines](contributing.md).
